//********************************************************************
//*** ResourcePool/SQL/Instances.cc
//*** Copyright (c) 2003-2008 by Markus Winand <mws@fatalmind.com>
//*** $Id: Instances.cc,v 1.15 2008/01/27 16:42:28 mws Exp $
//********************************************************************
/*
This file is part of ResourcePool.

ResourcePool is free software; you can redistribute it
and/or modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

ResourcePool is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied warranty
of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with ResourcePool; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307  USA */

#include "ResourcePool/ResourcePool.hh"
#include "ResourcePool/ResourcePool.cc"
#include "ResourcePool/Execute.cc"
#include "ResourcePool/Command.cc"
#include "ResourcePool/BatchCommand.cc"
#include "ResourcePool/SQL/Factory.cc"
#include "ResourcePool/SQL/Resource.cc"
#include "ResourcePool/SQL/ResourcePool.hh"

#ifdef HAVE_MYSQL_TRANSACTIONS
#include "ResourcePool/mysql/ResourcePool.hh"
#endif

#ifdef HAVE_ORACLE
#include "ResourcePool/oracle/ResourcePool.hh"
#include "ResourcePool/oracle/Resource.hh"
#endif

namespace fatalmind {
namespace SQL {

template class SQLFactory<DefaultThreadedModel>;
//template class SQLFactory<MultiThreadedModel<> >;

template class SQLResource<DefaultThreadedModel>;
//template class SQLResource<MultiThreadedModel<> >;

#ifdef HAVE_ORACLE
template class SQL::SQLResourceSpecialized<DefaultThreadedModel, fatalmind::ResourceType::oracle::resource_t>;
#endif

#ifdef HAVE_MYSQL_TRANSACTIONS
template class SQL::SQLResourceSpecialized<DefaultThreadedModel, fatalmind::ResourceType::mysql::resource_t>;
#endif

} // namespace SQL

template class ResourcePool<ResourceType::SQL>;
template class Command<ResourceType::SQL>;
template class BatchCommand< Command<ResourceType::SQL> >;


} //namespace fatalmind

